@@ -11,29 +11,12 @@ from modelcluster.fields import ParentalKey
 from modelcluster.models import ClusterableModel
 from wagtail.core.models import Orderable
 from wagtail.admin.edit_handlers import InlinePanel
+from wagtail.snippets.edit_handlers import SnippetChooserPanel
 
-LANGUAGE_FR = 'fr'
-LANGUAGE_EN = 'en'
-LANGUAGE_DE = 'de'
-LANGUAGE_NL = 'nl'
-LANGUAGE_ES = 'es'
-LANGUAGE_IT = 'it'
-LANGUAGES = [
-    (LANGUAGE_FR, 'French'),
-    (LANGUAGE_EN, 'English'),
-    (LANGUAGE_DE, 'German'),
-    (LANGUAGE_NL, 'Dutch'),
-    (LANGUAGE_ES, 'Spanish'),
-    (LANGUAGE_IT, 'Italian'),
-]
-LOCALES = {
-    LANGUAGE_FR: 'fr-FR',
-    LANGUAGE_EN: 'en-EN',
-    LANGUAGE_DE: 'de-DE',
-    LANGUAGE_NL: 'nl-NL',
-    LANGUAGE_ES: 'es-ES',
-    LANGUAGE_IT: 'it-IT',
-}
+from webspace.loader import get_model
+from webspace.cms import constants
+
+Form = get_model('cms', 'Form')
 
 
 class AFounders(Orderable):
@@ -64,12 +47,19 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
     instagram = models.URLField(blank=True, help_text='Instagram page URL')
     linkedin = models.URLField(blank=True, help_text='Linkedin page URL')
     twitter = models.URLField(blank=True, help_text='Twitter page URL')
+    pinterest = models.URLField(blank=True, help_text='Pinterest page URL')
+    youtube = models.URLField(blank=True, help_text='Youtube page URL')
 
     brand_name = models.CharField(default='', blank=True, max_length=100)
-    logo_header = StreamField([
+    logo_header_primary = StreamField([
         ('image', ImageChooserBlock(label="Image - ratio 200x55")),
         ('svg', DocumentChooserBlock(label="Svg - ratio 200x55")),
     ], blank=True)
+    logo_header_secondary = StreamField([
+        ('image', ImageChooserBlock(label="Image - ratio 200x55")),
+        ('svg', DocumentChooserBlock(label="Svg - ratio 200x55")),
+    ], blank=True)
+
     logo_schema = models.ForeignKey(
         'wagtailimages.Image',
         null=True,
@@ -94,7 +84,7 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         help_text="Google Analytics - Code de suivis"
     )
     language = models.CharField(
-        choices=LANGUAGES,
+        choices=constants.LANGUAGES,
         default='',
         blank=True,
         max_length=100,
@@ -110,6 +100,15 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         default='',
         help_text="Text qui apparait sur un block Social Share"
     )
+    newsletter = models.ForeignKey(
+        Form,
+        null=True,
+        blank=True,
+        on_delete=models.SET_NULL,
+        related_name='+',
+        verbose_name="Newsletter Formulaire",
+    )
+
     vat_id = models.CharField(default='', blank=True, max_length=100)
     legal_name = models.CharField(default='', blank=True, max_length=100)
     founding_date = models.DateField(blank=True, default=None, null=True)
@@ -126,7 +125,8 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         FieldPanel('language'),
         FieldPanel('ga_code'),
         FieldPanel('collect_text'),
-        FieldPanel('social_share_text')
+        FieldPanel('social_share_text'),
+        SnippetChooserPanel('newsletter')
     ]
 
     socials_panels = [
@@ -134,11 +134,14 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         FieldPanel('instagram'),
         FieldPanel('linkedin'),
         FieldPanel('twitter'),
+        FieldPanel('youtube'),
+        FieldPanel('pinterest'),
     ]
 
     brand_tab_panels = [
         FieldPanel('brand_name'),
-        StreamFieldPanel('logo_header'),
+        StreamFieldPanel('logo_header_primary'),
+        StreamFieldPanel('logo_header_secondary'),
         ImageChooserPanel('favicon'),
         ImageChooserPanel('logo_schema'),
     ]
@@ -172,4 +175,4 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
 
     @property
     def locale(self):
-        return LOCALES[self.language] if self.language in LOCALES else ''
+        return constants.LOCALES[self.language] if self.language in constants.LOCALES else ''
