@@ -5,7 +5,9 @@ import Cms from './helpers/Cms';
   Cms.SmoothScroll.init();
   Cms.Carousel.init();
   Cms.Clicker.init();
-  Cms.Accordion.init();
+  Cms.Aside.mobile();
   Cms.Lazy.init();
   Cms.Collect.init();
+  Cms.Accordion.init();
+  Cms.CounterUp.init();
 }());
